function hide(el) {
    if (!el.hasAttribute('displayOld')) {
        el.setAttribute("displayOld", el.style.display);
    }	 
    el.style.display = "none";
}

function getRealDisplay(elem) {
	if (elem.currentStyle) {
		return elem.currentStyle.display;
	} else if (window.getComputedStyle) {
		var computedStyle = window.getComputedStyle(elem, null);
		return computedStyle.getPropertyValue('display');
	} 
}

function isHidden(el) {
	var width = el.offsetWidth, height = el.offsetHeight, tr = el.nodeName.toLowerCase() === "tr";

	return width === 0 && height === 0 && !tr ?
		true : width > 0 && height > 0 && !tr ? false : getRealDisplay(el);
}


displayCache = {};

function show(el) {
	if (getRealDisplay(el) != 'none') return;

	el.style.display = el.getAttribute("displayOld") || "";

	if ( getRealDisplay(el) === "none" ) {
		var nodeName = el.nodeName, body = document.body, display;

		if ( displayCache[nodeName] ) {
			display = displayCache[nodeName];
		} else {
			var testElem = document.createElement(nodeName);
			body.appendChild(testElem);
			display = getRealDisplay(testElem);

			if (display === "none" ) {
				display = "block";
			}

			body.removeChild(testElem);
			displayCache[nodeName] = display;
		}

		el.setAttribute('displayOld', display);
		el.style.display = display;
	}
}



function bindReady(handler){
	var called = false;

	function ready() { // (1)
		if (called) return;
		called = true;
		handler();
	}

	if ( document.addEventListener ) { // (2)
		document.addEventListener( "DOMContentLoaded", function(){
			ready();
		}, false )
	} else if ( document.attachEvent ) {  // (3)

		// (3.1)
		if ( document.documentElement.doScroll && window == window.top ) {
			function tryScroll(){
				if (called) return;
				if (!document.body) return;
				try {
					document.documentElement.doScroll("left");
					ready();
				} catch(e) {
					setTimeout(tryScroll, 0);
				}
			}
			tryScroll();
		}

		// (3.2)
		document.attachEvent("onreadystatechange", function(){

			if ( document.readyState === "complete" ) {
				ready();
			}
		})
	}

	// (4)
    if (window.addEventListener)
        window.addEventListener('load', ready, false)
    else if (window.attachEvent)
        window.attachEvent('onload', ready);
    /*  else  // (4.1)
        window.onload=ready
	*/
}

readyList = [];

function onReady(handler) {
	if (!readyList.length) {
		bindReady(function() {
			for(var i=0; i<readyList.length; i++) {
				readyList[i]();
			}
		})
	}
	readyList.push(handler);
}
